<?php
/*
  KeepAliveQB.php
  Opens ODBC connection to host Quickbooks DB for 'n' hours.
  Reads a small table every 'x' minutes to keep alive.
  If there are any connection or read errors, writes to sync log.
  If sync log is by user, user is 'system'.
  Also emails any errors, if these params are defined with values:
    EMAIL_PEAR           = true
    EMAIL_HOST           = [valid email host URL]
    EMAIL_SYNC_ERRORS    = true
    EMAIL_SYNC_ERRORS_TO = [valid email address(es)]
    EMAIL_SYNC_ERRORS_CC = [optional email address(es)]
    EMAIL_FROM           = [valid email address]

  TLD 2013.03.10 Original version
  CMI 2015.01.27 Modify to use latest jsi_functions library.
*/

$hoursToRun = 12;  // run this many hours, then exit
$minPerReq  = 30;  // #minutes between requests to host QB DB

$QB_Table   = 'Terms';       // table to read on each request
$g_rep      = 'system';      // in case logs are by user
$scriptName = 'KeepAliveQB';

# required include files (in current directory)
require_once 'jsi.php';
require_once 'jsi_config.php';
require_once 'jsi_css.php';
require_once 'jsi_database.php';
require_once 'jsi_functions.php';
if (EMAIL_PEAR)
  require_once "Mail.php";


function CLI_To_CGI() {
  if ( CLI_CLIENT &&
       isset($_SERVER['argc']) &&
       isset($_SERVER['argv']) &&
       $_SERVER['argc'] > 0 ) {
    for ($i=1;$i<$_SERVER['argc'];$i++) {
      parse_str($_SERVER['argv'][$i],$tmp);
      $_REQUEST = array_merge($_REQUEST, $tmp);
    }
  }
}

/* ** main logic section **
** get procedure name, edit it and run it if ok
** log each request to a text log file
*/

CLI_To_CGI();

CheckLogSize();
BeginLogEntry();
WriteLog("$scriptName: Connect to Quickbooks via ODBC ");
$curr_ts = date('Y-m-d H:i:s');
WriteLog("$scriptName: Start time: $curr_ts");

$db = DB_DATABASE;
if (!jsi_db_connect(DB_SERVER,DB_SERVER_USERNAME,DB_SERVER_PASSWORD,$db)) {
  WarnLogAndEmail("$scriptName: Could not connect to QB DB: " . $db);
  return false;
}

$tot_minutes = 60 * (int)$hoursToRun;
$run_minutes = 0;
while ($run_minutes < $tot_minutes) {
  sleep(60 * (int)$minPerReq);  // sleep 'n' seconds (minutes times 60 sec/min)
  WriteLog("$scriptName: try to read QB $QB_Table table");
  $query_stmt = "SELECT * FROM $QB_Table";
  $result = jsi_db_query($query_stmt);
  if (!$result) {
    WarnLogAndEmail("$scriptName: Attempt to read $QB_Table table failed");
    break;
  }
  jsi_db_free_result($result);  // Free resultset
  $run_minutes += (int)$minPerReq;
}
jsi_db_close();

$curr_ts = date('Y-m-d H:i:s');
WriteLog("$scriptName: End time: $curr_ts");
EndLogEntry();

?>
